@@ -48,49 +48,123 @@ hand, can store any Unicode code point.
 Of course, Perl doesn’t I<always> optimize “bytes-compatible” strings;
 Perl can also, if
 it wants, store such strings “unoptimized” (i.e., in Perl’s internal
-“loose UTF-8” format), too. For code points 0-127 there’s actually no
+“loose UTF-8” format), too. For code points 0-127 (ASCII printables,
+controls, and DEL) there’s actually no
 difference between the two forms, but for 128-255 the formats differ. (cf.
 L<perlunicode/The "Unicode Bug">) This means that anything that reads
 Perl’s internals B<MUST> differentiate between the two forms in order to
 use the string correctly.
 
-Alas, that differentiation doesn’t always happen. Thus, Perl can
-output a string that stores one or more 128-255 code points
-differently depending on whether Perl has “optimized” that string or not.
+Alas, that differentiation doesn’t always happen. When it doesn’t, Perl
+outputs code points 128-255 differently depending on whether the
+containing string is “optimized” or not.
 
 Remember, though: Perl applications I<should> I<not> I<care> about
-Perl’s string storage internals. (This is why, for example, the L<bytes>
+Perl’s string storage internals like optimized/unoptimized. (This is why,
+for example, the L<bytes>
 pragma is discouraged.) The catch, though, is that without that knowledge,
 B<the> B<application> B<can’t> B<know> B<what> B<it> B<actually> B<says>
 B<to> B<the> B<outside> B<world!>
 
 Thus, applications must either monitor Perl’s string-storage internals
-or accept unpredictable behaviour, both of which are categorically bad.
+or accept unpredictable behavior, both of which are categorically bad.
+
+(Perl’s documentation calls the “unoptimized” format “upgraded”, while
+it calls the “optimized” format “downgraded”. The rest of this document
+will favor Perl’s terms.)
 
 =head1 HOW THIS MODULE (PARTLY) FIXES THE PROBLEM
 
-This module provides predictable behaviour for Perl’s built-in functions by
+This module provides predictable behavior for Perl’s built-in functions by
 downgrading all strings before giving them to the operating system. It’s
 equivalent to—but faster than!—prefixing your system calls with
 C<utf8::downgrade()> (cf. L<utf8>) on all arguments.
 
-Predictable behaviour is B<always> a good thing; ergo, you should
+Predictable behavior is B<always> a good thing; ergo, you should
 use this module in B<all> new code.
 
 =head1 CAVEAT: CHARACTER ENCODING
 
 If you apply this module injudiciously to existing code you may see
-exceptions thrown where previously things worked just fine. This can
+exceptions or character corruption where previously things worked fine.
+
+This can
 happen if you’ve neglected to encode one or more strings before
-sending them to the OS; if Perl has such a string stored upgraded then
-Perl will, under default behaviour, send a UTF-8-encoded
-version of that string to the OS. In essence, it’s an implicit
-UTF-8 auto-encode.
+sending them to the OS. Without Sys::Binmode, Perl sends upgraded
+strings to the OS in UTF-8 encoding. In essence, it’s an implicit
+UTF-8 auto-encode, which is kind of nice, except that it depends on
+Perl’s internals, which are unpredictable. Sys::Binmode removes
+that implicit UTF-8 auto-encode, which of course will break things
+that need it.
 
 The fix is to apply an explicit UTF-8 encode prior to the system call
 that throws the error. This is what we should do I<anyway>;
 Sys::Binmode just enforces that better.
 
+=head2 Example: The L<utf8> Pragma
+
+The widely-used L<utf8> pragma particularly exemplifies this problem.
+
+If you have code like this:
+
+    use utf8;
+
+    mkdir "épée";
+
+… then adding this module will change your program’s behavior in ways you’ll
+probably dislike.
+
+Consider the string C<épée>. Without the C<utf8> pragma (but assuming that
+the code I<is> actually written in UTF-8) this is 6
+characters because the two C<é>s are 2 bytes each (so 2 + 1 + 2 + 1),
+and without the C<utf8> pragma each byte in a string constant becomes its own
+character, even if multiple bytes make up a single UTF-8 character. Since
+nothing I<probably> upgrades that string on its way to
+C<mkdir()>, the OS will receive the intended 6 bytes and create a directory
+with a UTF-8-encoded name.
+
+I<With> C<utf8>, though, C<épée> is B<4> characters, not 6, because
+this string is now UTF-8-decoded. Those 4 characters all lie beneath 256,
+so the string is still bytes-compatible. Thus, if you C<print()> that string
+you’ll get 4 bytes of Latin-1, which probably B<isn’t> what you want.
+
+C<mkdir()>, though, I<probably> still creates a directory with a 6-byte (UTF-8)
+name. This happens when Perl itself stores C<épée> in upgraded (i.e.,
+“unoptimized”) form. If that’s the case, that means Perl’s I<internal> buffer
+of C<épée> is still the 6 bytes of UTF-8, even though to the Perl
+I<application> it’s a 4-character string. Perl’s C<mkdir()> doesn’t care
+about characters, though; it just gives Perl’s internal buffer to the
+OS’s create-directory function. So by violating its own abstraction, Perl
+happens to achieve something that is I<sometimes> useful.
+
+There are still two problems, though:
+
+=over
+
+=item * 1. Inconsistency: C<print()> sends 4 bytes to the OS while
+C<mkdir()> (again, I<probably>) outputs 6.
+
+=item * 2. Uncertainty: C<épée> I<could> be stored downgraded rather than
+upgraded, which would cause C<mkdir()> to send 4 bytes instead.
+
+=back
+
+C<print()>’s outputting of 4 bytes here is actually the B<correct> behavior
+because it doesn’t depend on whether Perl stores the string upgraded or
+downgraded. Sys::Binmode extends that correct behavior to C<mkdir()> and
+other such Perl commands.
+
+To get what you want, just encode your string for output before you give it
+to the OS (as you should do anyway):
+
+    use utf8;
+    use Encode;
+
+    mkdir encode_utf8("épée");
+
+Now adding Sys::Binmode to your module will change nothing. It I<will>,
+though, make any future omitted-encoding bugs more apparent.
+
 =head2 Non-POSIX Operating Systems (e.g., Windows)
 
 In a POSIX operating system, an application’s communication with the
@@ -109,7 +183,7 @@ please file a bug.
 
 =head1 WHERE ELSE THIS PROBLEM CAN APPEAR
 
-The unpredictable-behaviour problem that this module fixes in core Perl is
+The unpredictable-behavior problem that this module fixes in core Perl is
 also common in XS modules due to rampant
 use of L<the SvPV macro|https://perldoc.perl.org/perlapi#SvPV> and
 variants. SvPV is like the L<bytes> pragma in C: it gives you the string’s
@@ -126,7 +200,7 @@ So XS authors should also avoid the default typemap for such conversions.
 
 =head1 LEXICAL SCOPING
 
-If, for some reason, you I<want> Perl’s unpredictable default behaviour,
+If, for some reason, you I<want> Perl’s unpredictable default behavior,
 you can disable this module for a given block via
 C<no Sys::Binmode>, thus:
 
@@ -171,9 +245,9 @@ If you’d like them, ask.
 
 =item * There’s room for optimization, if that’s gainful.
 
-=item * Ideally this behaviour should be in Perl’s core distribution.
+=item * Ideally this behavior should be in Perl’s core distribution.
 
-=item * Even more ideally, Perl should adopt this behaviour as I<default>.
+=item * Even more ideally, Perl should adopt this behavior as I<default>.
 Maybe someday!
 
 =back
@@ -182,7 +256,7 @@ Maybe someday!
 
 #----------------------------------------------------------------------
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.02_02';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
